import React from "react";
import ReactDOM from "react-dom/client";
import App from "./routes/App.jsx";
import "./index.css";
import 'react-datetime/css/react-datetime.css';
import AuthWrapper from './authentication/auth_wrapper.jsx'; // Import the AuthWrapper component
import OTPWrapper from "./authentication/otp_wrapper.jsx";
import { Navigate } from 'react-router-dom';

import { RouterProvider, createBrowserRouter } from "react-router-dom";
import ImportTable from "./import/main_import.jsx";
import { Provider } from "react-redux";
import imwstore from "./store/index.js";
import Users_Table from "./manage_users/table.jsx";
import UsersForm from "./manage_users/form.jsx";
import ViewProfile from "./manage_users/view.jsx";
import ManageRoles from "./manage_users/manageroles.jsx";
import ImportForm from "./import/patient_form.jsx";
import PatientList from "./import/patient-list.jsx";
import PatientTable from "./patients/assigned_patients.jsx";
import ResponseTable from "./patients/response_patients.jsx";
import PasswordForm from "./authentication/password.jsx";
import Main from "./masterdata/country/main.jsx";
import MainSection from "./masterdata/state/main.jsx";
import MainCity from "./masterdata/city/main.jsx";
import MainDepartment from "./masterdata/department/main.jsx";
import MainRelation from "./masterdata/relations/main.jsx";
import MainRole from "./masterdata/role/main.jsx";
import MainGender from "./masterdata/gender/main.jsx";
import MainAge from "./masterdata/age/main.jsx";
import MainFAQ from "./masterdata/faq-menu/main.jsx";
import MainCategory from "./masterdata/faq-categories/main.jsx";
import MainStatus from "./masterdata/status/main.jsx";
import MainAction from "./masterdata/access_status/main.jsx";
import MainAccount from "./masterdata/account_status/main.jsx";
import MainJob from "./masterdata/job_title/main.jsx";
import MainPick from "./masterdata/pick_drop_points/main.jsx";
import MainHospital from "./configuration/hospitals/main.jsx";
import MainEmailTemplate from "./configuration/mail_template/main.jsx";
import MainSMSConfig from "./configuration/sms_template/main.jsx";
import MainDoctype from "./configuration/doctype/main.jsx";
import MainLogo from "./configuration/logo/main.jsx";
import PatientProfile from "./patients/patient_profile.jsx";
import EditPatient from "./patients/edit_patients.jsx";
import MainAppointment from "./operations/appointments/main.jsx";
import MainInvitation from "./operations/invitation/main.jsx";
import MainPickDrop from "./operations/pickDrop/main.jsx";
import MainDoctor from "./operations/doctor_profile/main.jsx";
import MainConsultation from "./operations/online_consultation/main.jsx";
import MainAddFaq from "./operations/add_faq/main.jsx";
import NotFoundPage from "./authentication/error_404_page.jsx";
import Logout from "./authentication/logout.jsx";
import Dashboard from "./dashboard/overall_status.jsx";
import MainDashboardFaq from "./dashboard/faq_dashboard.jsx";

//http import page 
import { jwtDecode } from "jwt-decode";
import auth from "./services/auth.js";
import ChangePasswordForm from "./authentication/change_password.jsx";
import Notifications from "./notifications/notifications.jsx";
import LoginWrapper from "./authentication/login_wrapper.jsx";
import MainCompany from "./configuration/company/main.jsx";
import MainReferredBy from "./masterdata/referredBy/main.jsx";
import FolderView from "./dashboard/folderView.jsx";
import MainReCaptcha from "./configuration/reCaptcha/main.jsx";
import MainPDFDrive from "./configuration/savePDFDrive/main.jsx";
import OTPPasswordWrapper from "./authentication/otp_wrapper_password.jsx";
import PasswordWrapper from "./authentication/password_wrapper.jsx";
import PasswordCreation from "./authentication/passwordCreation.jsx";
import PasswordOTP from "./authentication/passwordOTP.jsx";
import MainInvoiceStatus from "./masterdata/invoice_status/main.jsx";
import MainCurrency from "./masterdata/currency/main.jsx";
import MainPaymentMode from "./masterdata/payment_mode/main.jsx";
import MainInvoiceAddressBank from "./masterdata/invoice_address_bank/main.jsx";
import MainAttendant from "./invoice/attendant/main.jsx";
import MainInvoiceYearRange from "./masterdata/invoice_year_range/main.jsx";
import MainRelease from "./masterdata/release/main.jsx";


const token = auth.getUser();
let decoded = "";
if (token) {
  decoded = jwtDecode(token);
}
const storedEmail = localStorage.getItem('email');

const router = createBrowserRouter([
  {
    path: "/",
    element: (
      <AuthWrapper>
        <App decoded={decoded} />
      </AuthWrapper>
    ),
    children: [
      { path: '/', element: <Dashboard decoded={decoded} /> },
      {
        path: '/faq_dashboard',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainDashboardFaq decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/folder_view',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <FolderView decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/imports',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Coordinator"].includes(decoded.user_role) ? (
          <ImportTable decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/users',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <Users_Table decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/edit_user',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <UsersForm decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/add_users',
        element: decoded && ["Super Admin"].includes(decoded.user_role) ? (
          <UsersForm decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/view_profile',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Hospital Coordinator", "Medical Assistant", "Viewer"].includes(decoded.user_role) ? (
          <ViewProfile decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/manage_roles',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <ManageRoles decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/form_patient/:index/:id',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <ImportForm decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/form_patient',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <ImportForm decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/patient_list',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <PatientList decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/assigned_patients',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <PatientTable decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/response_patients',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <ResponseTable decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/invoice_attendant',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant"].includes(decoded.user_role) ? (
          <MainAttendant decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/country',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <Main decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/states',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainSection decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/cities',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainCity decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/department',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainDepartment decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/release',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainRelease decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/relation',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainRelation decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/role',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainRole decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/invoice_status',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainInvoiceStatus decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/currency',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainCurrency decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/payment_mode',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainPaymentMode decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/address_bank',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainInvoiceAddressBank decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/invoice_year_range',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainInvoiceYearRange decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/gender',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainGender decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/age',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainAge decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/faq_menu',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainFAQ decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/faq_categories',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainCategory decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/status',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainStatus decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/referredBy',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainReferredBy decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/access_status',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainAction decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/account_status',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainAccount decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/job_title',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainJob decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/pick_drop',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainPick decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/hospitals',
        element: decoded && ["Super Admin"].includes(decoded.user_role) ? (
          <MainHospital decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/company',
        element: decoded && ["Super Admin"].includes(decoded.user_role) ? (
          <MainCompany decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/reCaptcha',
        element: decoded && ["Super Admin"].includes(decoded.user_role) ? (
          <MainReCaptcha decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/savePDFToDrive',
        element: decoded && ["Super Admin"].includes(decoded.user_role) ? (
          <MainPDFDrive decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/hospitals',
        element: decoded && ["Super Admin", "Admin", "Data Manager"].includes(decoded.user_role) ? (
          <MainHospital decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/mail_template',
        element: decoded && ["Super Admin"].includes(decoded.user_role) ? (
          <MainEmailTemplate decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/sms_template',
        element: decoded && ["Super Admin"].includes(decoded.user_role) ? (
          <MainSMSConfig decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/doctype',
        element: decoded && ["Super Admin"].includes(decoded.user_role) ? (
          <MainDoctype decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/logo',
        element: decoded && ["Super Admin"].includes(decoded.user_role) ? (
          <MainLogo decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/patient_profile',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <PatientProfile decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/edit_patient',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <EditPatient decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/appointment',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <MainAppointment decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/invitation',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <MainInvitation decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/pickdrop',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <MainPickDrop decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/doctors_profile',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <MainDoctor decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/online_consultation',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <MainConsultation decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/add_faq',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <MainAddFaq decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/change_password',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <ChangePasswordForm decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
      {
        path: '/notifications',
        element: decoded && ["Super Admin", "Admin", "Data Manager", "Medical Assistant", "Coordinator"].includes(decoded.user_role) ? (
          <Notifications decoded={decoded} />
        ) : (
          <Navigate to="/404" />
        )
      },
    ],
  },
  // { path: "/login", element: <Login /> },
  // { path: "/OTP", element: <OTPForm /> },
  // { path: "/password/:id", element: <PasswordForm /> },
  // { path: "/404", element: <NotFoundPage /> },
  // { path: "/logout", element: <Logout /> },
  {
    path: "/login", element: <LoginWrapper />
  },
  {
    path: "/OTP", element: <OTPWrapper /> // Use the OTPWrapper component
  },
  {
    path: "/password/:id",
    element: storedEmail ? <PasswordForm /> : <Navigate to="/" />
  },
  {
    path: "/404",
    element: <NotFoundPage />
  },
  {
    path: "/passwordCreation",
    element: <PasswordCreation />
  },
  {
    path: "/password_verification_OTP",
    element: <PasswordOTP />
  },
  {
    path: "/logout",
    element: <Logout />
  },
  {
    path: "*",
    element: <Navigate to="/404" />
  },
]);

ReactDOM.createRoot(document.getElementById("app-container")).render(
  <React.StrictMode>
    <Provider store={imwstore}>
      <RouterProvider router={router} />
    </Provider>
  </React.StrictMode>
);
